# **********************************************************************
#
# Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************

#
# This file is included by Make.rules when uname is Linux.
#

USE_SPARC_ASM           = irrelevant
MACHINE                 = $(shell uname -m)

#
# Default compiler is c++ (aka g++).
#
ifeq ($(CXX),)
   CXX			= c++
endif

ifeq ($(CXX),g++)
   CXX			= c++
endif

#
# icecpp is built with a C compiler
#
CFLAGS = -g -O2

ifeq ($(MACHINE),x86_64)
   ifeq ($(LP64),yes)
      CFLAGS	+= -m64
   else
      CFLAGS	+= -m32
   endif
endif

ifeq ($(CXX),c++)

   ifeq ($(MACHINE),sparc64)
      #
      # We are an ultra, at least, and so have the atomic instructions
      #
      $(warning ===================================================================) 
      $(warning Linux on SPARC is currently unsupported. The Ice team does not)
      $(warning maintain SPARC specific portions of the source code or build)
      $(warning system. Contact sales@zeroc.com if you wish to sponsor official)
      $(warning support.)
      $(warning ===================================================================) 
      USE_SPARC_ASM	= yes
      CXXARCHFLAGS	= -mcpu=ultrasparc -pipe -Wno-deprecated -DUSE_SPARC_ASM
   endif

   ifeq ($(MACHINE),sparc)
      #
      # We are a sun4m or sun4c
      # On sun4m, there is a bug in some CPU/kernel/gcc configurations which
      # prevent us from using '-mcpu=v8'
      #
      $(warning ===================================================================) 
      $(warning Linux on SPARC is currently unsupported. The Ice team does not)
      $(warning maintain SPARC specific portions of the source code or build)
      $(warning system. Contact sales@zeroc.com if you wish to sponsor official)
      $(warning support.)
      $(warning ===================================================================) 
      USE_SPARC_ASM	= no
      CXXARCHFLAGS	= -mtune=v8 -pipe -Wno-deprecated -DICE_USE_MUTEX_SHARED
   endif

   ifeq ($(MACHINE),x86_64)
      ifeq ($(LP64),yes)
         CXXARCHFLAGS	+= -m64
      else
         CXXARCHFLAGS	+= -m32
      endif
   endif

   CXXFLAGS		= $(CXXARCHFLAGS) -ftemplate-depth-128 -Wall -D_REENTRANT -I/usr/include/nptl -D_REENTRANT -DHAVE_ENDIAN_H -DHAVE_LIMITS_H

   ifneq ($(GENPIC),no)
      CXXFLAGS		+= -fPIC
   endif

   ifeq ($(OPTIMIZE),yes)
      CXXFLAGS		+= -g -O2 -DNDEBUG
   else
      CXXFLAGS		+= -g 
   endif

   ifeq ($(USE_SPARC_ASM),yes)
      CFLAGS		= -g -O2 -mcpu=ultrasparc -pipe -DNDEBUG -DUSE_SPARC_ASM
      ifneq ($(GENPIC),no)
         CFLAGS		+= -fPIC
      endif
   endif
   ifeq ($(USE_SPARC_ASM),no)
      CFLAGS		= -g -O2 -mcpu=v8 -pipe -DNDEBUG -DICE_USE_MUTEX_SHARED
      ifneq ($(GENPIC),no)
         CFLAGS		+= -fPIC
      endif
   endif

   #
   # C++ run-time libraries, necessary for linking some shared libraries.
   #
   CXXLIBS		=

   mkshlib		= $(CXX) -shared $(LDFLAGS) -o $(1) -Wl,-h,$(2) $(3) $(4) -lpthread -lrt

   mklib		= ar cr $(1) $(2)

   rpathlink            = -Wl,-rpath-link,$(1) 

   ifneq ($(embedded_runpath_prefix),)
      LDPLATFORMFLAGS      = -Wl,--enable-new-dtags -Wl,-rpath,$(runpath_libdir)
   else
      LDPLATFORMFLAGS      = -Wl,--enable-new-dtags
   endif

endif

ifeq ($(CXX),icpc)
   $(warning ===================================================================) 
   $(warning Intel C++ is currently not supported. The Ice team does not)
   $(warning maintain Intel C++ specific portions of the source code or build)
   $(warning system.  Contact sales@zeroc.com if you wish to sponsor official)
   $(warning support.)
   $(warning ===================================================================) 
   CXXFLAGS		= -D_REENTRANT    

   ifneq ($(GENPIC),no)
      CXXFLAGS		+= -fPIC
   endif

   ifeq ($(OPTIMIZE),yes)
      CXXFLAGS		+= -g -O2 -DNDEBUG
   else
      CXXFLAGS		+= -g
   endif

   #
   # C++ run-time libraries, necessary for linking some shared libraries.
   #
   CXXLIBS		=

   mkshlib		= $(CXX) -shared $(LDFLAGS) -o $(1) -Wl,-h,$(2) $(3) $(4) -lpthread -lrt

   mklib		= ar cr $(1) $(2)

   rpathlink            = -Wl,-rpath-link,$(1) 

endif

NPTL_LIB		= /usr/$(libsubdir)/nptl

BASELIBS		= -lIceUtil -L$(NPTL_LIB) -lpthread
LIBS			= $(BZIP2_RPATH_LINK) -lIce $(BASELIBS)

ICEUTIL_OS_LIBS         = 
ICE_OS_LIBS             = -ldl

PLATFORM_HAS_READLINE   = yes

